@@ -15,10 +15,14 @@
 #include <QDateTime>
 #include <QStringList>
 
+#include <memory>
+
 class KConfigSkeleton;
 
 namespace IncidenceEditorNG
 {
+class EditorConfigPrivate;
+
 /**
  * Configuration details. An application can inherit from this class
  * to provide application specific configurations to the editor.
@@ -101,8 +105,7 @@ public:
     Q_REQUIRED_RESULT virtual QStringList &templates(KCalendarCore::IncidenceBase::IncidenceType type);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<EditorConfigPrivate> const d;
 };
 }
 
